# -*- coding: utf-8 -*-
'''
Advanced Interface Switcher Config
2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.config import Config
from advpowcommon.util.singleton import Singleton

class AISConfig(Config, Singleton):

  def __init__(self, settings_path):
    Config.__init__(self, settings_path)
    Singleton.__init__(self)

__config_singleton = AISConfig('/apps/advanced-interface-switcher')
def get(): return __config_singleton
